@@ -1,4 +1,4 @@
-# $Id: mirror_sites.tcl 80216 2011-07-07 03:09:52Z blair@macports.org $
+# $Id: mirror_sites.tcl 92764 2012-05-06 00:16:52Z ryandesign@macports.org $
 # mirror_sites.tcl
 #
 # List of master site classes for use in Portfiles
@@ -14,23 +14,23 @@ namespace eval portfetch::mirror_sites { }
 
 set portfetch::mirror_sites::sites(afterstep) {
     ftp://ftp.kddlabs.co.jp/X11/AfterStep/
-    ftp://ftp.chg.ru/pub/X11/windowmanagers/afterstep/
     ftp://ftp.dti.ad.jp/pub/X/AfterStep/
     ftp://ftp.afterstep.org/
 }
 
 set portfetch::mirror_sites::sites(apache) {
-    http://www.ibiblio.org/pub/mirrors/apache/
+    http://mirrors.ibiblio.org/apache/
     http://www.gtlib.gatech.edu/pub/apache/
     http://apache.mirror.rafal.ca/
-    http://apache.mirroring.de/
     ftp://ftp.infoscience.co.jp/pub/net/apache/dist/
     http://apache.multidist.com/
     http://mirror.internode.on.net/pub/apache/
+    http://www.mirrorservice.org/sites/ftp.apache.org/
     http://mirror.aarnet.edu.au/pub/apache/
     http://apache-mirror.dkuug.dk/
     http://apache.is.co.za/
     http://mirror.facebook.net/apache/
+    http://apache.pesat.net.id/
     http://www.apache.org/dist/
     http://archive.apache.org/dist/
 }
@@ -76,14 +76,23 @@ set portfetch::mirror_sites::sites(fink) {
     http://distfiles.dub.ie.eu.finkmirrors.net/:nosubdir
     http://distfiles.ams.nl.eu.finkmirrors.net/:nosubdir
     http://distfiles.sjc.ca.us.finkmirrors.net/:nosubdir
+    http://www.mirrorservice.org/sites/master.us.finkmirrors.net/distfiles/:nosubdir
     http://distfiles.master.finkmirrors.net/:nosubdir
 }
 
 set portfetch::mirror_sites::sites(freebsd) {
+    http://ftp4.FreeBSD.org/pub/FreeBSD/ports/distfiles/:nosubdir
+    http://ftp4.FreeBSD.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
     ftp://ftp5.freebsd.org/pub/FreeBSD/ports/distfiles/:nosubdir
     ftp://ftp5.freebsd.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
+    http://ftp10.FreeBSD.org/pub/FreeBSD/ports/distfiles/:nosubdir
+    http://ftp10.FreeBSD.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
+    http://ftp14.FreeBSD.org/pub/FreeBSD/ports/distfiles/:nosubdir
+    http://ftp14.FreeBSD.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
     ftp://ftp.uk.FreeBSD.org/pub/FreeBSD/ports/distfiles/:nosubdir
     ftp://ftp.uk.FreeBSD.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
+    http://www.mirrorservice.org/sites/ftp.freebsd.org/pub/FreeBSD/ports/distfiles/:nosubdir
+    http://www.mirrorservice.org/sites/ftp.freebsd.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
     ftp://ftp.jp.FreeBSD.org/pub/FreeBSD/ports/distfiles/:nosubdir
     ftp://ftp.jp.FreeBSD.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
     ftp://ftp.tw.FreeBSD.org/pub/FreeBSD/ports/distfiles/:nosubdir
@@ -94,6 +103,8 @@ set portfetch::mirror_sites::sites(freebsd) {
     ftp://ftp.se.FreeBSD.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
     http://mirror.aarnet.edu.au/pub/FreeBSD/ports/distfiles/:nosubdir
     http://mirror.aarnet.edu.au/pub/FreeBSD/ports/local-distfiles/:nosubdir
+    http://ftp.FreeBSD.org/pub/FreeBSD/ports/distfiles/:nosubdir
+    http://ftp.FreeBSD.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
     ftp://ftp.FreeBSD.org/pub/FreeBSD/ports/distfiles/:nosubdir
     ftp://ftp.FreeBSD.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
 }
@@ -107,7 +118,7 @@ set portfetch::mirror_sites::sites(gentoo) {
     http://gentoo.c3sl.ufpr.br/distfiles/:nosubdir
     http://gentoo.inode.at/distfiles/:nosubdir
     http://mirror.bih.net.ba/gentoo/distfiles/:nosubdir
-    http:/distfiles.gentoo.bg/distfiles/:nosubdir
+    http://distfiles.gentoo.bg/distfiles/:nosubdir
     http://ftp.fi.muni.cz/pub/linux/gentoo/distfiles/:nosubdir
     http://ftp.klid.dk/ftp/gentoo/distfiles/:nosubdir
     http://trumpetti.atm.tut.fi/gentoo/distfiles/:nosubdir
@@ -126,12 +137,12 @@ set portfetch::mirror_sites::sites(gentoo) {
     http://gentoo.prz.rzeszow.pl/distfiles/:nosubdir
     http://darkstar.ist.utl.pt/gentoo/distfiles/:nosubdir
     http://mirrors.evolva.ro/gentoo/distfiles/:nosubdir
-    http://gentoo.ynet.sk/pub/distfiles/:nosubdir
     http://gentoo-euetib.upc.es/mirror/gentoo/distfiles/:nosubdir
     http://ftp.ds.karen.hj.se/gentoo/distfiles/:nosubdir
     http://mirror.switch.ch/ftp/mirror/gentoo/distfiles/:nosubdir
     http://ftp.linux.org.tr/gentoo/distfiles/:nosubdir
     http://mirror.bytemark.co.uk/gentoo/distfiles/:nosubdir
+    http://www.mirrorservice.org/sites/www.ibiblio.org/gentoo/distfiles/:nosubdir
     http://gentoo.kiev.ua/ftp/distfiles/:nosubdir
     http://ftp.swin.edu.au/gentoo/distfiles/:nosubdir
     http://ftp.iij.ad.jp/pub/linux/gentoo/distfiles/:nosubdir
@@ -145,25 +156,43 @@ set portfetch::mirror_sites::sites(gentoo) {
 }
 
 set portfetch::mirror_sites::sites(gimp) {
-    ftp://ftp.gtk.org/pub/
     http://ftp.gtk.org/pub/
+    ftp://ftp.gtk.org/pub/
+    ftp://ftp.gimp.org/pub/
     http://gimp.mirrors.hoobly.com/
+    http://gimp.cp-dev.com/
+    http://gimp.promotionalpromos.com/
+    http://gimp.sixsigmaonline.org/
+    http://www.mirrorservice.org/sites/ftp.gimp.org/pub/
+    http://piotrkosoft.net/pub/mirrors/ftp.gimp.org/pub/
     ftp://gd.tuwien.ac.at/graphics/gimp/
+    ftp://ftp.funet.fi/pub/sci/graphics/packages/
     http://ftp.iut-bm.univ-fcomte.fr/gimp/
     ftp://ftp.gwdg.de/pub/misc/grafik/gimp/
     http://ftp.gwdg.de/pub/misc/grafik/gimp/
     ftp://ftp.esat.net/mirrors/ftp.gimp.org/pub/
     http://ftp.esat.net/mirrors/ftp.gimp.org/pub/
+    ftp://ftp.heanet.ie/mirrors/ftp.gimp.org/pub/
+    http://ftp.heanet.ie/mirrors/ftp.gimp.org/pub/
     ftp://ftp.u-aizu.ac.jp/pub/graphics/tools/gimp/
+    ftp://ftp.ring.gr.jp/pub/graphics/
+    http://www.ring.gr.jp/pub/graphics/
     ftp://ftp.snt.utwente.nl/pub/software/gimp/
     http://ftp.snt.utwente.nl/pub/software/gimp/
+    ftp://sunsite.icm.edu.pl/pub/graphics/
     ftp://ftp.sai.msu.su/pub/unix/graphics/gimp/mirror/
+    http://sunsite.rediris.es/mirror/
+    ftp://ftp.rediris.es/mirror/
     ftp://ftp.acc.umu.se/pub/gimp/
+    ftp://ftp.sunet.se/pub/gnu/
+    http://ftp.sunet.se/pub/gnu/
+    ftp://ftp.is.co.za/mirror/ftp.gimp.org/
 }
 
 set portfetch::mirror_sites::sites(gnome) {
     ftp://ftp.cse.buffalo.edu/pub/Gnome/
-    http://www.gtlib.cc.gatech.edu/pub/gnome/
+    http://www.gtlib.gatech.edu/pub/gnome/
+    http://www.mirrorservice.org/sites/ftp.gnome.org/pub/GNOME/
     http://fr2.rpmfind.net/linux/gnome.org/
     http://mirror.aarnet.edu.au/pub/gnome/
     http://ftp.unina.it/pub/linux/GNOME/
@@ -173,7 +202,6 @@ set portfetch::mirror_sites::sites(gnome) {
     ftp://ftp.dit.upm.es/pub/GNOME/
     ftp://ftp.no.gnome.org/pub/GNOME/
     ftp://ftp.nara.wide.ad.jp/pub/X11/GNOME/
-    ftp://ftp.chg.ru/pub/X11/gnome/
     ftp://ftp.kddlabs.co.jp/pub/GNOME/
     http://mirror.internode.on.net/pub/gnome/
     http://ftp.df.lth.se/pub/gnome/
@@ -182,8 +210,8 @@ set portfetch::mirror_sites::sites(gnome) {
 }
 
 set portfetch::mirror_sites::sites(gnu) {
-    http://mirrors.ibiblio.org/pub/mirrors/gnu/ftp/gnu/
-    http://mirrors.kernel.org/gnu/
+    http://mirrors.ibiblio.org/gnu/ftp/gnu/
+    http://www.mirrorservice.org/sites/ftp.gnu.org/gnu/
     http://mirror.facebook.net/gnu/gnu/
     ftp://ftp.funet.fi/pub/gnu/prep/
     ftp://ftp.kddlabs.co.jp/pub/gnu/gnu/
@@ -191,15 +219,16 @@ set portfetch::mirror_sites::sites(gnu) {
     ftp://ftp.dti.ad.jp/pub/GNU/
     ftp://ftp.informatik.hu-berlin.de/pub/gnu/gnu/
     ftp://ftp.lip6.fr/pub/gnu/
-    ftp://ftp.chg.ru/pub/gnu/
     http://mirror.internode.on.net/pub/gnu/
     http://mirror.aarnet.edu.au/pub/gnu/
+    ftp://ftp.unicamp.br/pub/gnu/
     ftp://ftp.gnu.org/gnu/
     http://ftp.gnu.org/gnu/
     ftp://ftp.gnu.org/old-gnu/
 }
 
 set portfetch::mirror_sites::sites(gnupg) {
+    http://www.mirrorservice.org/sites/ftp.gnupg.org/gcrypt/
     ftp://gd.tuwien.ac.at/privacy/gnupg/
     http://ftp.freenet.de/pub/ftp.gnupg.org/gcrypt/
     ftp://ftp.jyu.fi/pub/crypt/gcrypt/
@@ -217,17 +246,19 @@ set portfetch::mirror_sites::sites(googlecode) {
 }
 
 set portfetch::mirror_sites::sites(isc) {
-    ftp://ftp.epix.net/pub/isc/
+    http://www.mirrorservice.org/sites/ftp.isc.org/isc/
     ftp://ftp.nominum.com/pub/isc/
     http://mirrors.24-7-solutions.net/pub/isc/
+    http://www.mirrorservice.org/sites/ftp.isc.org/isc/
     ftp://gd.tuwien.ac.at/infosys/servers/isc/
+    http://ftp.arcane-networks.fr/pub/mirrors/ftp.isc.org/isc/
     ftp://ftp.ciril.fr/pub/isc/
-    ftp://ftp.grolier.fr/pub/isc/
     ftp://ftp.funet.fi/pub/mirrors/ftp.isc.org/isc/
     ftp://ftp.freenet.de/pub/ftp.isc.org/isc/
     ftp://ftp.fsn.hu/pub/isc/
     ftp://ftp.iij.ad.jp/pub/network/isc/
     ftp://ftp.dti.ad.jp/pub/net/isc/
+    http://ftp.kaist.ac.kr/pub/isc/
     ftp://ftp.task.gda.pl/mirror/ftp.isc.org/isc/
     ftp://ftp.sunet.se/pub/network/isc/
     ftp://ftp.ripe.net/mirrors/sites/ftp.isc.org/isc/
@@ -239,17 +270,15 @@ set portfetch::mirror_sites::sites(isc) {
 
 set portfetch::mirror_sites::sites(kde) {
     http://mirrors.mit.edu/kde/
-    http://ibiblio.org/pub/mirrors/kde/
     http://kde.mirrors.hoobly.com/
-    http://ftp.gtlib.cc.gatech.edu/pub/kde/
+    http://ftp.gtlib.gatech.edu/pub/kde/
+    http://www.mirrorservice.org/sites/ftp.kde.org/pub/kde/
     http://gd.tuwien.ac.at/kde/
     http://mirrors.isc.org/pub/kde/
     http://kde.mirrors.tds.net/pub/kde/
-    ftp://ftp.oregonstate.edu/pub/kde/
     ftp://ftp.solnet.ch/mirror/KDE/
     http://mirror.internode.on.net/pub/kde/
-    http://mirror.aarnet.edu.au/pub/kde/
-    http://ftp.chg.ru/pub/kde/
+    http://mirror.aarnet.edu.au/pub/KDE/
     http://ftp.kddlabs.co.jp/pub/X11/kde/
     ftp://ftp.kde.org/pub/kde/
     http://mirror.facebook.net/kde/
@@ -262,6 +291,8 @@ set portfetch::mirror_sites::sites(macports) {
 set portfetch::mirror_sites::sites(macports_distfiles) {
     http://distfiles.macports.org/:mirror
     http://aarnet.au.distfiles.macports.org/pub/macports/mpdistfiles/:mirror
+    http://her.gr.distfiles.macports.org/mirrors/macports/mpdistfiles/:mirror
+    http://jog.id.distfiles.macports.org/macports/mpdistfiles/:mirror
     http://lil.fr.distfiles.macports.org/:mirror
     http://sea.us.distfiles.macports.org/macports/mpdistfiles/:mirror
     http://ykf.ca.distfiles.macports.org/MacPorts/mpdistfiles/:mirror
@@ -279,9 +310,11 @@ set portfetch::mirror_sites::sites(netbsd) {
 }
 
 set portfetch::mirror_sites::sites(openbsd) {
+    http://www.mirrorservice.org/sites/ftp.openbsd.org/pub/OpenBSD/
     ftp://carroll.cac.psu.edu/pub/OpenBSD/
     ftp://openbsd.informatik.uni-erlangen.de/pub/OpenBSD/
     ftp://gd.tuwien.ac.at/opsys/OpenBSD/
+    http://ftp.ch.openbsd.org/pub/OpenBSD/
     ftp://ftp.stacken.kth.se/pub/OpenBSD/
     ftp://ftp3.usa.openbsd.org/pub/OpenBSD/
     ftp://rt.fm/pub/OpenBSD/
@@ -289,12 +322,12 @@ set portfetch::mirror_sites::sites(openbsd) {
     ftp://ftp.jp.openbsd.org/pub/OpenBSD/
     http://mirror.internode.on.net/pub/OpenBSD/
     http://mirror.aarnet.edu.au/pub/OpenBSD/
-    ftp://ftp.chg.ru/pub/OpenBSD/
     ftp://ftp.openbsd.org/pub/OpenBSD/
 }
 
 set portfetch::mirror_sites::sites(perl_cpan) {
-    http://mirrors.ibiblio.org/pub/mirrors/CPAN/modules/by-module/
+    http://mirrors.ibiblio.org/CPAN/modules/by-module/
+    http://www.mirrorservice.org/sites/ftp.cpan.org/pub/CPAN/modules/by-module/
     http://ftp.ucr.ac.cr/Unix/CPAN/modules/by-module/
     ftp://ftp.funet.fi/pub/languages/perl/CPAN/modules/by-module/
     ftp://ftp.kddlabs.co.jp/lang/perl/CPAN/modules/by-module/
@@ -303,7 +336,6 @@ set portfetch::mirror_sites::sites(perl_cpan) {
     ftp://ftp.auckland.ac.nz/pub/perl/CPAN/modules/by-module/
     ftp://ftp.cs.colorado.edu/pub/perl/CPAN/modules/by-module/
     ftp://ftp.is.co.za/programming/perl/modules/by-module/
-    ftp://ftp.chg.ru/pub/lang/perl/CPAN/modules/by-module/
     http://mirror.internode.on.net/pub/cpan/modules/by-module/
     http://cpan.mirrors.ilisys.com.au/modules/by-module/
     http://mirror.aarnet.edu.au/pub/CPAN/modules/by-module/
@@ -317,15 +349,17 @@ set portfetch::mirror_sites::sites(php) {
     http://es.php.net/distributions/:nosubdir
     http://fi.php.net/distributions/:nosubdir
     http://fr2.php.net/distributions/:nosubdir
+    http://id.php.net/distributions/:nosubdir
     http://jp2.php.net/distributions/:nosubdir
-    http://uk2.php.net/distributions/:nosubdir
+    http://uk3.php.net/distributions/:nosubdir
     http://us.php.net/distributions/:nosubdir
     http://us2.php.net/distributions/:nosubdir
     http://www.php.net/distributions/:nosubdir
 }
 
 set portfetch::mirror_sites::sites(postgresql) {
-    http://ftp9.us.postgresql.org/pub/mirrors/postgresql/
+    http://ftp.postgresql.org/pub/
+    http://www.mirrorservice.org/sites/ftp.postgresql.org/
     http://ftp7.de.postgresql.org/ftp.postgresql.org/
     ftp://ftp2.ch.postgresql.org/pub/mirrors/postgresql
     ftp://ftp.de.postgresql.org/mirror/postgresql/
@@ -337,14 +371,13 @@ set portfetch::mirror_sites::sites(postgresql) {
 }
 
 set portfetch::mirror_sites::sites(ruby) {
-    http://www.ibiblio.org/pub/languages/ruby/
-    http://mirrors.sunsite.dk/ruby/
+    http://mirrors.ibiblio.org/ruby/
+    http://www.mirrorservice.org/sites/ftp.ruby-lang.org/pub/ruby/
     ftp://xyz.lcs.mit.edu/pub/ruby/
     ftp://ftp.iij.ad.jp/pub/lang/ruby/
     ftp://ftp.fu-berlin.de/unix/languages/ruby/
     ftp://ftp.easynet.be/ruby/ruby/
     ftp://ftp.ntua.gr/pub/lang/ruby/
-    ftp://ftp.chg.ru/pub/lang/ruby/
     ftp://ftp.iDaemons.org/pub/mirror/ftp.ruby-lang.org/ruby/
     http://ftp.ruby-lang.org/pub/ruby/
     ftp://ftp.ruby-lang.org/pub/ruby/
@@ -421,39 +454,37 @@ set portfetch::mirror_sites::sites(sourceforge_jp) {
 
 set portfetch::mirror_sites::sites(sunsite) {
     http://www.ibiblio.org/pub/Linux/
-    http://www.gtlib.cc.gatech.edu/pub/Linux/
+    http://www.gtlib.gatech.edu/pub/Linux/
     ftp://sunsite.unc.edu/pub/Linux/
     ftp://ftp.unicamp.br/pub/systems/Linux/
     ftp://ftp.tuwien.ac.at/pub/linux/ibiblio/
     ftp://ftp.cs.tu-berlin.de/pub/linux/Mirrors/sunsite.unc.edu/
     ftp://ftp.lip6.fr/pub/linux/sunsite/
-    http://ftp.surfnet.nl/pub/sunsite/
+    http://ftp.nluug.nl/pub/sunsite/
     ftp://ftp.nvg.ntnu.no/pub/mirrors/metalab.unc.edu/
     ftp://ftp.icm.edu.pl/vol/rzm1/linux-ibiblio/
     ftp://ftp.cse.cuhk.edu.hk/pub4/Linux/
     ftp://ftp.kddlabs.co.jp/Linux/metalab.unc.edu/
-    ftp://ftp.chg.ru/pub/Linux/sunsite/
 }
 
 set portfetch::mirror_sites::sites(tcltk) {
+    http://www.mirrorservice.org/sites/ftp.tcl.tk/pub/tcl/
     ftp://mirror.switch.ch/mirror/tcl.tk/
     ftp://ftp.informatik.uni-hamburg.de/pub/soft/lang/tcl/
     ftp://ftp.funet.fi/pub/languages/tcl/tcl/
     ftp://ftp.kddlabs.co.jp/lang/tcl/ftp.scriptics.com/
     http://www.etsimo.uniovi.es/pub/mirrors/ftp.scriptics.com/
-    http://ftp.chg.ru/pub/lang/tcl/
     ftp://ftp.tcl.tk/pub/tcl/
 }
 
 set portfetch::mirror_sites::sites(tex_ctan) {
-    http://mirrors.ibiblio.org/pub/mirrors/CTAN/
+    http://mirrors.ibiblio.org/CTAN/
     http://ctan.math.utah.edu/ctan/tex-archive/
     ftp://ftp.funet.fi/pub/TeX/CTAN/
     http://mirror.internode.on.net/pub/ctan/
     ftp://ctan.unsw.edu.au/tex-archive/
     http://mirror.aarnet.edu.au/pub/CTAN/
     ftp://ftp.kddlabs.co.jp/CTAN/
-    ftp://ftp.chg.ru/pub/TeX/CTAN/
     ftp://mirror.macomnet.net/pub/CTAN/
     http://ftp.sun.ac.za/ftp/CTAN/
     http://ftp.inf.utfsm.cl/pub/tex-archive/
@@ -473,15 +504,16 @@ set portfetch::mirror_sites::sites(trolltech) {
 
 set portfetch::mirror_sites::sites(xcontrib) {
     ftp://ftp.net.ohio-state.edu/pub/X11/contrib/
+    http://www.mirrorservice.org/sites/ftp.x.org/contrib/
     ftp://ftp.gwdg.de/pub/x11/x.org/contrib/
     http://mirror.aarnet.edu.au/pub/X11/contrib/
-    ftp://ftp.chg.ru/pub/X11/x.org/contrib/
     ftp://ftp2.x.org/contrib/
     ftp://ftp.x.org/contrib/
 }
 
 set portfetch::mirror_sites::sites(xfree) {
-    http://www.gtlib.cc.gatech.edu/pub/XFree86/
+    http://www.gtlib.gatech.edu/pub/XFree86/
+    http://www.mirrorservice.org/sites/ftp.xfree86.org/pub/XFree86/
     http://ftp-stud.fht-esslingen.de/pub/Mirrors/ftp.xfree86.org/XFree86/
     ftp://ftp.fit.vutbr.cz/pub/XFree86/
     ftp://ftp.gwdg.de/pub/xfree86/XFree86/
@@ -493,16 +525,15 @@ set portfetch::mirror_sites::sites(xfree) {
 
 set portfetch::mirror_sites::sites(xorg) {
     http://mirror.csclub.uwaterloo.ca/x.org/
+    http://www.mirrorservice.org/sites/ftp.x.org/pub/
     http://mirror.switch.ch/ftp/mirror/X11/pub/
     ftp://ftp.gwdg.de/pub/x11/x.org/pub/
     http://ftp.cica.es/mirrors/X/pub/
-    http://mirror.cict.fr/x.org/pub/
     ftp://ftp.ntua.gr/pub/X11/X.org/
     ftp://ftp.cs.cuhk.edu.hk/pub/X11/
     http://mi.mirror.garr.it/mirrors/x.org/
     http://ftp.nara.wide.ad.jp/pub/X11/x.org/
     ftp://sunsite.uio.no/pub/X11/
-    ftp://ftp.task.gda.pl/mirror/ftp.x.org/pub/
     ftp://ftp.sunet.se/pub/X11/ftp.x.org/
     http://x.cs.pu.edu.tw/
     ftp://ftp.is.co.za/pub/x.org/pub/
