@@ -1,7 +1,7 @@
 # et:ts=4
 # gnustep.tcl
 #
-# $Id: gnustep-1.0.tcl 63198 2010-01-29 08:13:26Z ryandesign@macports.org $
+# $Id: gnustep-1.0.tcl 73714 2010-11-22 12:22:22Z jmr@macports.org $
 #
 # Copyright (c) 2006 Yves de Champlain <yves@opendarwin.org>,
 # All rights reserved.
@@ -170,12 +170,10 @@ proc set_gnustep_env {} {
     global env prefix
     
     if {[gnustep_layout]} {
-        return "\
-            DYLD_LIBRARY_PATH=${prefix}/GNUstep/Local/Library/Libraries:${prefix}/GNUstep/System/Library/Libraries \
-            PATH=${prefix}/GNUstep/Local/Tools:${prefix}/GNUstep/System/Tools:$env(PATH) \
-        "
+        return [list "DYLD_LIBRARY_PATH=${prefix}/GNUstep/Local/Library/Libraries:${prefix}/GNUstep/System/Library/Libraries" \
+            "PATH=${prefix}/GNUstep/Local/Tools:${prefix}/GNUstep/System/Tools:$env(PATH)"]
     }
-    return
+    return [list]
 }
 
 #
@@ -185,7 +183,13 @@ proc set_gnustep_env {} {
 options gnustep.cc
 default gnustep.cc          {CC=${configure.cc}}
 
-configure.compiler          macports-gcc-4.2
+platform darwin 8 {
+    configure.compiler      apple-gcc-4.2
+    depends_build           port:apple-gcc42
+}
+platform darwin 9 {
+    configure.compiler      gcc-4.2
+}
 
 options system_library
 options local_library
