@@ -1,4 +1,4 @@
-# $Id: sourceforge.tcl 52378 2009-06-15 12:46:30Z nox@macports.org $
+# $Id: sourceforge.tcl 73509 2010-11-16 06:41:36Z jmr@macports.org $
 #
 # This file contains the defaults for sourceforge.
 
@@ -12,12 +12,12 @@ if {${livecheck.name} eq "default"} {
     }
 }
 if {!$has_homepage || ${livecheck.url} eq ${homepage}} {
-    set livecheck.url "http://sourceforge.net/export/rss2_projfiles.php?project=${livecheck.name}"
+    set livecheck.url "http://sourceforge.net/api/file/index/project-name/${livecheck.name}/rss"
 }
 if {${livecheck.distname} eq "default"} {
     set livecheck.distname ${livecheck.name}
 }
 if {${livecheck.regex} eq ""} {
-    set livecheck.regex [list "(?i)<title>[quotemeta ${livecheck.distname}] (.*) released.*</title>"]
+    set livecheck.regex [list "/[quotemeta ${livecheck.distname}]/(\[a-zA-Z0-9.\]+\\.\[a-zA-Z0-9.\]+)/"]
 }
 set livecheck.type "regex"
