@@ -1,5 +1,5 @@
---- src/common/pa_types.h.orig	2009-07-16 12:37:32.000000000 -0700
-+++ src/common/pa_types.h	2009-07-16 12:37:50.000000000 -0700
+--- src/common/pa_types.h.orig	2006-08-26 17:27:53.000000000 +0900
++++ src/common/pa_types.h	2012-01-07 20:26:17.000000000 +0900
 @@ -62,7 +62,11 @@
  #endif
  
