@@ -5,7 +5,7 @@
     
     opt_start = (u_char *)(tcp + 1);
 -   opt_end = (u_char *)((int)tcp + tcp->off * 4);
-+   opt_end = (u_char *)(tcp + tcp->off * 4);
++   opt_end = (u_char *)((unsigned long)tcp + tcp->off * 4);
  
     DECODED_LEN = (u_int32)(tcp->off * 4);
  
