@@ -1,10 +1,14 @@
 --- pam-support.c.orig	Wed Aug 11 17:34:14 2004
 +++ pam-support.c	Wed Aug 11 17:34:16 2004
-@@ -21,7 +21,11 @@
+@@ -21,7 +21,15 @@
  
  #include "logging.h"
  
-+#ifdef __APPLE__
++#if defined(__APPLE__)
++#include <AvailabilityMacros.h>
++#endif
++
++#if defined(__APPLE__) && defined(MAC_OS_X_VERSION_MIN_REQUIRED) && (MAC_OS_X_VERSION_MIN_REQUIRED < 1060)
 +#include <pam/pam_appl.h>
 +#else
  #include <security/pam_appl.h>
