@@ -1,15 +1,15 @@
---- main/archives.c.orig	Thu Nov 11 20:10:03 2004
-+++ main/archives.c	Fri Dec 17 17:34:55 2004
-@@ -312,6 +312,7 @@
- int tarobject(struct TarInfo *ti) {
+--- src/archives.c.orig	Thu Nov 11 20:10:03 2004
++++ src/archives.c	Fri Dec 17 17:34:55 2004
+@@ -373,6 +373,7 @@
    static struct varbuf conffderefn, hardlinkfn, symlinkfn;
+   static int fd;
    const char *usename;
 +  char *s = NULL;
-     
+ 
+   struct conffile *conff;
    struct tarcontext *tc= (struct tarcontext*)ti->UserData;
-   int statr, fd, i, existingdirectory;
-@@ -357,7 +358,15 @@
-                 divpkg ? ")" : "");
+@@ -423,7 +424,15 @@
+     }
    }
  
 -  usename= namenodetouse(nifd->namenode,tc->pkg)->name + 1; /* Skip the leading `/' */
@@ -25,7 +25,7 @@
  
    if (nifd->namenode->flags & fnnf_new_conff) {
      /* If it's a conffile we have to extract it next to the installed
-@@ -369,6 +378,10 @@
+@@ -435,6 +444,10 @@
    }
    
    setupfnamevbs(usename);
