@@ -1,6 +1,6 @@
---- main/remove.c.orig	Fri Dec 10 15:48:16 2004
-+++ main/remove.c	Fri Dec 10 15:51:29 2004
-@@ -254,7 +254,18 @@
+--- src/remove.c.orig	Fri Dec 10 15:48:16 2004
++++ src/remove.c	Fri Dec 10 15:51:29 2004
+@@ -266,7 +266,18 @@
          push_leftover(&leftover,namenode);
          continue;
        }
@@ -20,7 +20,7 @@
        debug(dbg_eachfiledetail, "removal_bulk unlinking `%s'", fnvb.buf);
        {
          /*
-@@ -367,7 +378,18 @@
+@@ -383,7 +394,18 @@
        push_leftover(&leftover,namenode);
        continue;
      }
