@@ -1,5 +1,5 @@
---- xmove/server.c	Sun Aug  3 21:36:45 1997
-+++ ../../xmove.patches/xmove/server.c	Tue Mar 22 10:28:17 2005
+--- xmove/server.c.orig	1997-08-03 14:36:45.000000000 -0500
++++ xmove/server.c	2011-06-13 03:47:06.000000000 -0500
 @@ -40,7 +40,6 @@
  #include <sys/time.h>          /* for struct timeval * */
  #include <errno.h>             /* for EINTR, EADDRINUSE, ... */
